@@ -3,8 +3,9 @@ Main interface for datasync service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.datasync import (
+    from mypy_boto3_datasync import (
         Client,
         DataSyncClient,
         ListAgentsPaginator,
@@ -12,7 +13,7 @@ Usage::
         ListTagsForResourcePaginator,
         ListTaskExecutionsPaginator,
         ListTasksPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -24,6 +25,7 @@ Usage::
     list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
     list_task_executions_paginator: ListTaskExecutionsPaginator = client.get_paginator("list_task_executions")
     list_tasks_paginator: ListTasksPaginator = client.get_paginator("list_tasks")
+    ```
 """
 from mypy_boto3_datasync.client import DataSyncClient as Client, DataSyncClient
 from mypy_boto3_datasync.paginator import (
