@@ -3,8 +3,11 @@ Main interface for datasync service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.datasync import (
+
+    from mypy_boto3_datasync import DataSyncClient
+    from mypy_boto3_datasync import (
         ListAgentsPaginator,
         ListLocationsPaginator,
         ListTagsForResourcePaginator,
@@ -19,6 +22,7 @@ Usage::
     list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
     list_task_executions_paginator: ListTaskExecutionsPaginator = client.get_paginator("list_task_executions")
     list_tasks_paginator: ListTasksPaginator = client.get_paginator("list_tasks")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, TYPE_CHECKING
@@ -44,64 +48,64 @@ __all__ = (
 
 class ListAgentsPaginator(Boto3Paginator):
     """
-    [Paginator.ListAgents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/datasync.html#DataSync.Paginator.ListAgents)
+    [Paginator.ListAgents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/datasync.html#DataSync.Paginator.ListAgents)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListAgentsResponseTypeDef]:
         """
-        [ListAgents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/datasync.html#DataSync.Paginator.ListAgents.paginate)
+        [ListAgents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/datasync.html#DataSync.Paginator.ListAgents.paginate)
         """
 
 
 class ListLocationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListLocations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/datasync.html#DataSync.Paginator.ListLocations)
+    [Paginator.ListLocations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/datasync.html#DataSync.Paginator.ListLocations)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListLocationsResponseTypeDef]:
         """
-        [ListLocations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/datasync.html#DataSync.Paginator.ListLocations.paginate)
+        [ListLocations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/datasync.html#DataSync.Paginator.ListLocations.paginate)
         """
 
 
 class ListTagsForResourcePaginator(Boto3Paginator):
     """
-    [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
+    [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
     """
 
     def paginate(
         self, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListTagsForResourceResponseTypeDef]:
         """
-        [ListTagsForResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource.paginate)
+        [ListTagsForResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource.paginate)
         """
 
 
 class ListTaskExecutionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListTaskExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
+    [Paginator.ListTaskExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
     """
 
     def paginate(
         self, TaskArn: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListTaskExecutionsResponseTypeDef]:
         """
-        [ListTaskExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions.paginate)
+        [ListTaskExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions.paginate)
         """
 
 
 class ListTasksPaginator(Boto3Paginator):
     """
-    [Paginator.ListTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/datasync.html#DataSync.Paginator.ListTasks)
+    [Paginator.ListTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/datasync.html#DataSync.Paginator.ListTasks)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListTasksResponseTypeDef]:
         """
-        [ListTasks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.13/reference/services/datasync.html#DataSync.Paginator.ListTasks.paginate)
+        [ListTasks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/datasync.html#DataSync.Paginator.ListTasks.paginate)
         """
