@@ -3,9 +3,11 @@ Main interface for datasync service type definitions.
 
 Usage::
 
-    from mypy_boto3.datasync.type_defs import CreateAgentResponseTypeDef
+    ```python
+    from mypy_boto3_datasync.type_defs import AgentListEntryTypeDef
 
-    data: CreateAgentResponseTypeDef = {...}
+    data: AgentListEntryTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
@@ -22,6 +24,21 @@ else:
 
 
 __all__ = (
+    "AgentListEntryTypeDef",
+    "Ec2ConfigTypeDef",
+    "FilterRuleTypeDef",
+    "LocationListEntryTypeDef",
+    "NfsMountOptionsTypeDef",
+    "OnPremConfigTypeDef",
+    "OptionsTypeDef",
+    "PrivateLinkConfigTypeDef",
+    "S3ConfigTypeDef",
+    "SmbMountOptionsTypeDef",
+    "TagListEntryTypeDef",
+    "TaskExecutionListEntryTypeDef",
+    "TaskExecutionResultDetailTypeDef",
+    "TaskListEntryTypeDef",
+    "TaskScheduleTypeDef",
     "CreateAgentResponseTypeDef",
     "CreateLocationEfsResponseTypeDef",
     "CreateLocationFsxWindowsResponseTypeDef",
@@ -29,38 +46,132 @@ __all__ = (
     "CreateLocationS3ResponseTypeDef",
     "CreateLocationSmbResponseTypeDef",
     "CreateTaskResponseTypeDef",
-    "PrivateLinkConfigTypeDef",
     "DescribeAgentResponseTypeDef",
-    "Ec2ConfigTypeDef",
     "DescribeLocationEfsResponseTypeDef",
     "DescribeLocationFsxWindowsResponseTypeDef",
-    "NfsMountOptionsTypeDef",
-    "OnPremConfigTypeDef",
     "DescribeLocationNfsResponseTypeDef",
-    "S3ConfigTypeDef",
     "DescribeLocationS3ResponseTypeDef",
-    "SmbMountOptionsTypeDef",
     "DescribeLocationSmbResponseTypeDef",
-    "FilterRuleTypeDef",
-    "OptionsTypeDef",
-    "TaskExecutionResultDetailTypeDef",
     "DescribeTaskExecutionResponseTypeDef",
-    "TaskScheduleTypeDef",
     "DescribeTaskResponseTypeDef",
-    "AgentListEntryTypeDef",
     "ListAgentsResponseTypeDef",
-    "LocationListEntryTypeDef",
     "ListLocationsResponseTypeDef",
-    "TagListEntryTypeDef",
     "ListTagsForResourceResponseTypeDef",
-    "TaskExecutionListEntryTypeDef",
     "ListTaskExecutionsResponseTypeDef",
-    "TaskListEntryTypeDef",
     "ListTasksResponseTypeDef",
     "PaginatorConfigTypeDef",
     "StartTaskExecutionResponseTypeDef",
 )
 
+AgentListEntryTypeDef = TypedDict(
+    "AgentListEntryTypeDef",
+    {"AgentArn": str, "Name": str, "Status": Literal["ONLINE", "OFFLINE"]},
+    total=False,
+)
+
+Ec2ConfigTypeDef = TypedDict("Ec2ConfigTypeDef", {"SubnetArn": str, "SecurityGroupArns": List[str]})
+
+FilterRuleTypeDef = TypedDict(
+    "FilterRuleTypeDef", {"FilterType": Literal["SIMPLE_PATTERN"], "Value": str}, total=False
+)
+
+LocationListEntryTypeDef = TypedDict(
+    "LocationListEntryTypeDef", {"LocationArn": str, "LocationUri": str}, total=False
+)
+
+NfsMountOptionsTypeDef = TypedDict(
+    "NfsMountOptionsTypeDef",
+    {"Version": Literal["AUTOMATIC", "NFS3", "NFS4_0", "NFS4_1"]},
+    total=False,
+)
+
+OnPremConfigTypeDef = TypedDict("OnPremConfigTypeDef", {"AgentArns": List[str]})
+
+OptionsTypeDef = TypedDict(
+    "OptionsTypeDef",
+    {
+        "VerifyMode": Literal["POINT_IN_TIME_CONSISTENT", "ONLY_FILES_TRANSFERRED", "NONE"],
+        "OverwriteMode": Literal["ALWAYS", "NEVER"],
+        "Atime": Literal["NONE", "BEST_EFFORT"],
+        "Mtime": Literal["NONE", "PRESERVE"],
+        "Uid": Literal["NONE", "INT_VALUE", "NAME", "BOTH"],
+        "Gid": Literal["NONE", "INT_VALUE", "NAME", "BOTH"],
+        "PreserveDeletedFiles": Literal["PRESERVE", "REMOVE"],
+        "PreserveDevices": Literal["NONE", "PRESERVE"],
+        "PosixPermissions": Literal["NONE", "PRESERVE"],
+        "BytesPerSecond": int,
+        "TaskQueueing": Literal["ENABLED", "DISABLED"],
+        "LogLevel": Literal["OFF", "BASIC", "TRANSFER"],
+    },
+    total=False,
+)
+
+PrivateLinkConfigTypeDef = TypedDict(
+    "PrivateLinkConfigTypeDef",
+    {
+        "VpcEndpointId": str,
+        "PrivateLinkEndpoint": str,
+        "SubnetArns": List[str],
+        "SecurityGroupArns": List[str],
+    },
+    total=False,
+)
+
+S3ConfigTypeDef = TypedDict("S3ConfigTypeDef", {"BucketAccessRoleArn": str})
+
+SmbMountOptionsTypeDef = TypedDict(
+    "SmbMountOptionsTypeDef", {"Version": Literal["AUTOMATIC", "SMB2", "SMB3"]}, total=False
+)
+
+_RequiredTagListEntryTypeDef = TypedDict("_RequiredTagListEntryTypeDef", {"Key": str})
+_OptionalTagListEntryTypeDef = TypedDict(
+    "_OptionalTagListEntryTypeDef", {"Value": str}, total=False
+)
+
+
+class TagListEntryTypeDef(_RequiredTagListEntryTypeDef, _OptionalTagListEntryTypeDef):
+    pass
+
+
+TaskExecutionListEntryTypeDef = TypedDict(
+    "TaskExecutionListEntryTypeDef",
+    {
+        "TaskExecutionArn": str,
+        "Status": Literal[
+            "QUEUED", "LAUNCHING", "PREPARING", "TRANSFERRING", "VERIFYING", "SUCCESS", "ERROR"
+        ],
+    },
+    total=False,
+)
+
+TaskExecutionResultDetailTypeDef = TypedDict(
+    "TaskExecutionResultDetailTypeDef",
+    {
+        "PrepareDuration": int,
+        "PrepareStatus": Literal["PENDING", "SUCCESS", "ERROR"],
+        "TotalDuration": int,
+        "TransferDuration": int,
+        "TransferStatus": Literal["PENDING", "SUCCESS", "ERROR"],
+        "VerifyDuration": int,
+        "VerifyStatus": Literal["PENDING", "SUCCESS", "ERROR"],
+        "ErrorCode": str,
+        "ErrorDetail": str,
+    },
+    total=False,
+)
+
+TaskListEntryTypeDef = TypedDict(
+    "TaskListEntryTypeDef",
+    {
+        "TaskArn": str,
+        "Status": Literal["AVAILABLE", "CREATING", "QUEUED", "RUNNING", "UNAVAILABLE"],
+        "Name": str,
+    },
+    total=False,
+)
+
+TaskScheduleTypeDef = TypedDict("TaskScheduleTypeDef", {"ScheduleExpression": str})
+
 CreateAgentResponseTypeDef = TypedDict("CreateAgentResponseTypeDef", {"AgentArn": str}, total=False)
 
 CreateLocationEfsResponseTypeDef = TypedDict(
@@ -85,17 +196,6 @@ CreateLocationSmbResponseTypeDef = TypedDict(
 
 CreateTaskResponseTypeDef = TypedDict("CreateTaskResponseTypeDef", {"TaskArn": str}, total=False)
 
-PrivateLinkConfigTypeDef = TypedDict(
-    "PrivateLinkConfigTypeDef",
-    {
-        "VpcEndpointId": str,
-        "PrivateLinkEndpoint": str,
-        "SubnetArns": List[str],
-        "SecurityGroupArns": List[str],
-    },
-    total=False,
-)
-
 DescribeAgentResponseTypeDef = TypedDict(
     "DescribeAgentResponseTypeDef",
     {
@@ -105,19 +205,17 @@ DescribeAgentResponseTypeDef = TypedDict(
         "LastConnectionTime": datetime,
         "CreationTime": datetime,
         "EndpointType": Literal["PUBLIC", "PRIVATE_LINK", "FIPS"],
-        "PrivateLinkConfig": PrivateLinkConfigTypeDef,
+        "PrivateLinkConfig": "PrivateLinkConfigTypeDef",
     },
     total=False,
 )
 
-Ec2ConfigTypeDef = TypedDict("Ec2ConfigTypeDef", {"SubnetArn": str, "SecurityGroupArns": List[str]})
-
 DescribeLocationEfsResponseTypeDef = TypedDict(
     "DescribeLocationEfsResponseTypeDef",
     {
         "LocationArn": str,
         "LocationUri": str,
-        "Ec2Config": Ec2ConfigTypeDef,
+        "Ec2Config": "Ec2ConfigTypeDef",
         "CreationTime": datetime,
     },
     total=False,
@@ -136,28 +234,18 @@ DescribeLocationFsxWindowsResponseTypeDef = TypedDict(
     total=False,
 )
 
-NfsMountOptionsTypeDef = TypedDict(
-    "NfsMountOptionsTypeDef",
-    {"Version": Literal["AUTOMATIC", "NFS3", "NFS4_0", "NFS4_1"]},
-    total=False,
-)
-
-OnPremConfigTypeDef = TypedDict("OnPremConfigTypeDef", {"AgentArns": List[str]})
-
 DescribeLocationNfsResponseTypeDef = TypedDict(
     "DescribeLocationNfsResponseTypeDef",
     {
         "LocationArn": str,
         "LocationUri": str,
-        "OnPremConfig": OnPremConfigTypeDef,
-        "MountOptions": NfsMountOptionsTypeDef,
+        "OnPremConfig": "OnPremConfigTypeDef",
+        "MountOptions": "NfsMountOptionsTypeDef",
         "CreationTime": datetime,
     },
     total=False,
 )
 
-S3ConfigTypeDef = TypedDict("S3ConfigTypeDef", {"BucketAccessRoleArn": str})
-
 DescribeLocationS3ResponseTypeDef = TypedDict(
     "DescribeLocationS3ResponseTypeDef",
     {
@@ -171,16 +259,12 @@ DescribeLocationS3ResponseTypeDef = TypedDict(
             "GLACIER",
             "DEEP_ARCHIVE",
         ],
-        "S3Config": S3ConfigTypeDef,
+        "S3Config": "S3ConfigTypeDef",
         "CreationTime": datetime,
     },
     total=False,
 )
 
-SmbMountOptionsTypeDef = TypedDict(
-    "SmbMountOptionsTypeDef", {"Version": Literal["AUTOMATIC", "SMB2", "SMB3"]}, total=False
-)
-
 DescribeLocationSmbResponseTypeDef = TypedDict(
     "DescribeLocationSmbResponseTypeDef",
     {
@@ -189,51 +273,12 @@ DescribeLocationSmbResponseTypeDef = TypedDict(
         "AgentArns": List[str],
         "User": str,
         "Domain": str,
-        "MountOptions": SmbMountOptionsTypeDef,
+        "MountOptions": "SmbMountOptionsTypeDef",
         "CreationTime": datetime,
     },
     total=False,
 )
 
-FilterRuleTypeDef = TypedDict(
-    "FilterRuleTypeDef", {"FilterType": Literal["SIMPLE_PATTERN"], "Value": str}, total=False
-)
-
-OptionsTypeDef = TypedDict(
-    "OptionsTypeDef",
-    {
-        "VerifyMode": Literal["POINT_IN_TIME_CONSISTENT", "ONLY_FILES_TRANSFERRED", "NONE"],
-        "OverwriteMode": Literal["ALWAYS", "NEVER"],
-        "Atime": Literal["NONE", "BEST_EFFORT"],
-        "Mtime": Literal["NONE", "PRESERVE"],
-        "Uid": Literal["NONE", "INT_VALUE", "NAME", "BOTH"],
-        "Gid": Literal["NONE", "INT_VALUE", "NAME", "BOTH"],
-        "PreserveDeletedFiles": Literal["PRESERVE", "REMOVE"],
-        "PreserveDevices": Literal["NONE", "PRESERVE"],
-        "PosixPermissions": Literal["NONE", "PRESERVE"],
-        "BytesPerSecond": int,
-        "TaskQueueing": Literal["ENABLED", "DISABLED"],
-        "LogLevel": Literal["OFF", "BASIC", "TRANSFER"],
-    },
-    total=False,
-)
-
-TaskExecutionResultDetailTypeDef = TypedDict(
-    "TaskExecutionResultDetailTypeDef",
-    {
-        "PrepareDuration": int,
-        "PrepareStatus": Literal["PENDING", "SUCCESS", "ERROR"],
-        "TotalDuration": int,
-        "TransferDuration": int,
-        "TransferStatus": Literal["PENDING", "SUCCESS", "ERROR"],
-        "VerifyDuration": int,
-        "VerifyStatus": Literal["PENDING", "SUCCESS", "ERROR"],
-        "ErrorCode": str,
-        "ErrorDetail": str,
-    },
-    total=False,
-)
-
 DescribeTaskExecutionResponseTypeDef = TypedDict(
     "DescribeTaskExecutionResponseTypeDef",
     {
@@ -241,22 +286,20 @@ DescribeTaskExecutionResponseTypeDef = TypedDict(
         "Status": Literal[
             "QUEUED", "LAUNCHING", "PREPARING", "TRANSFERRING", "VERIFYING", "SUCCESS", "ERROR"
         ],
-        "Options": OptionsTypeDef,
-        "Excludes": List[FilterRuleTypeDef],
-        "Includes": List[FilterRuleTypeDef],
+        "Options": "OptionsTypeDef",
+        "Excludes": List["FilterRuleTypeDef"],
+        "Includes": List["FilterRuleTypeDef"],
         "StartTime": datetime,
         "EstimatedFilesToTransfer": int,
         "EstimatedBytesToTransfer": int,
         "FilesTransferred": int,
         "BytesWritten": int,
         "BytesTransferred": int,
-        "Result": TaskExecutionResultDetailTypeDef,
+        "Result": "TaskExecutionResultDetailTypeDef",
     },
     total=False,
 )
 
-TaskScheduleTypeDef = TypedDict("TaskScheduleTypeDef", {"ScheduleExpression": str})
-
 DescribeTaskResponseTypeDef = TypedDict(
     "DescribeTaskResponseTypeDef",
     {
@@ -269,9 +312,9 @@ DescribeTaskResponseTypeDef = TypedDict(
         "CloudWatchLogGroupArn": str,
         "SourceNetworkInterfaceArns": List[str],
         "DestinationNetworkInterfaceArns": List[str],
-        "Options": OptionsTypeDef,
-        "Excludes": List[FilterRuleTypeDef],
-        "Schedule": TaskScheduleTypeDef,
+        "Options": "OptionsTypeDef",
+        "Excludes": List["FilterRuleTypeDef"],
+        "Schedule": "TaskScheduleTypeDef",
         "ErrorCode": str,
         "ErrorDetail": str,
         "CreationTime": datetime,
@@ -279,73 +322,34 @@ DescribeTaskResponseTypeDef = TypedDict(
     total=False,
 )
 
-AgentListEntryTypeDef = TypedDict(
-    "AgentListEntryTypeDef",
-    {"AgentArn": str, "Name": str, "Status": Literal["ONLINE", "OFFLINE"]},
-    total=False,
-)
-
 ListAgentsResponseTypeDef = TypedDict(
     "ListAgentsResponseTypeDef",
-    {"Agents": List[AgentListEntryTypeDef], "NextToken": str},
+    {"Agents": List["AgentListEntryTypeDef"], "NextToken": str},
     total=False,
 )
 
-LocationListEntryTypeDef = TypedDict(
-    "LocationListEntryTypeDef", {"LocationArn": str, "LocationUri": str}, total=False
-)
-
 ListLocationsResponseTypeDef = TypedDict(
     "ListLocationsResponseTypeDef",
-    {"Locations": List[LocationListEntryTypeDef], "NextToken": str},
+    {"Locations": List["LocationListEntryTypeDef"], "NextToken": str},
     total=False,
 )
 
-_RequiredTagListEntryTypeDef = TypedDict("_RequiredTagListEntryTypeDef", {"Key": str})
-_OptionalTagListEntryTypeDef = TypedDict(
-    "_OptionalTagListEntryTypeDef", {"Value": str}, total=False
-)
-
-
-class TagListEntryTypeDef(_RequiredTagListEntryTypeDef, _OptionalTagListEntryTypeDef):
-    pass
-
-
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
-    {"Tags": List[TagListEntryTypeDef], "NextToken": str},
-    total=False,
-)
-
-TaskExecutionListEntryTypeDef = TypedDict(
-    "TaskExecutionListEntryTypeDef",
-    {
-        "TaskExecutionArn": str,
-        "Status": Literal[
-            "QUEUED", "LAUNCHING", "PREPARING", "TRANSFERRING", "VERIFYING", "SUCCESS", "ERROR"
-        ],
-    },
+    {"Tags": List["TagListEntryTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListTaskExecutionsResponseTypeDef = TypedDict(
     "ListTaskExecutionsResponseTypeDef",
-    {"TaskExecutions": List[TaskExecutionListEntryTypeDef], "NextToken": str},
-    total=False,
-)
-
-TaskListEntryTypeDef = TypedDict(
-    "TaskListEntryTypeDef",
-    {
-        "TaskArn": str,
-        "Status": Literal["AVAILABLE", "CREATING", "QUEUED", "RUNNING", "UNAVAILABLE"],
-        "Name": str,
-    },
+    {"TaskExecutions": List["TaskExecutionListEntryTypeDef"], "NextToken": str},
     total=False,
 )
 
 ListTasksResponseTypeDef = TypedDict(
-    "ListTasksResponseTypeDef", {"Tasks": List[TaskListEntryTypeDef], "NextToken": str}, total=False
+    "ListTasksResponseTypeDef",
+    {"Tasks": List["TaskListEntryTypeDef"], "NextToken": str},
+    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
